document.addEventListener('DOMContentLoaded', function() {
  const spinButton = document.getElementById("spin-button");
  const wheel = document.getElementById("fortune-wheel");
  const registerModal = document.getElementById("register-modal");
  const modalClose = document.getElementById("modal-close");
  const modalPrizeTitle = document.querySelector(".prize-title");
  const modalPrizeCode = document.querySelector(".prize-code");
  const modalPrizeInstruction = document.querySelector(".prize-instruction");
  const copyButton = document.getElementById("copy-promo");

  const labelMap = {
    "0.5": "0.5$",
    "1": "1$",
    "2": "2$",
    "5": "5$",
    "15": "15$",
    "50": "50$",
    "100": "100$",
    "LOSE": "LOSE"
  };

  const segments = ["0.5", "1", "2", "5", "15", "50", "100", "LOSE"];

  spinButton.addEventListener('click', function () {
    if (!userId) return;

    spinButton.disabled = true;

    fetch(`/spin?user_id=${userId}`)
      .then(res => res.json())
      .then(data => {
        console.log("📦 Сервер прислал:", data);

        if (data.error) {
          let errorMessage;
          if (data.error === "daily_limit") {
            errorMessage = "⏳ Сегодня вы уже крутили колесо. Приходите завтра!";
          } else if (data.error === "coef_zero") {
            errorMessage = "📉 Ваши шансы обнулились — сделайте депозит, чтобы снова крутить!";
          } else if (data.error === "no_deposit") {
            errorMessage = "🚫 Сначала сделайте депозит, чтобы крутить колесо!";
          } else if (data.error === "no_vouchers_available") {
            errorMessage = "😔 Ваучеры этого номинала закончились. Попробуйте позже!";
          } else {
            errorMessage = "❌ Произошла ошибка. Попробуйте позже.";
          }
          if (modalPrizeTitle) {
            modalPrizeTitle.textContent = errorMessage;
            modalPrizeCode.textContent = "";
            modalPrizeInstruction.textContent = "";
            copyButton.style.display = "none";
          }
          registerModal.classList.add("active");
          spinButton.disabled = false;
          return;
        }

        const result = data.result;
        const voucherCode = data.voucher_code || null;
        let index = typeof data.segment_index === 'number' ? data.segment_index : 0;
        const segmentSize = 45;
        const initialOffset = 22.5;

        wheel.style.transition = 'none';
        wheel.style.transform = `rotate(0deg)`;
        wheel.getBoundingClientRect();

        requestAnimationFrame(() => {
          const spinAngle = 360 * 5 - (index * segmentSize + initialOffset) + (Math.random() * 5 - 2.5);
          wheel.style.transition = 'transform 4.5s cubic-bezier(0.33, 1, 0.68, 1)';
          wheel.style.transform = `rotate(${spinAngle}deg)`;
        });

        setTimeout(() => {
          spinButton.disabled = false;
          registerModal.classList.add("active");
          const readableResult = labelMap[result] || result;
          if (result === "LOSE") {
            modalPrizeTitle.textContent = "Сегодня не повезло… Попробуй снова завтра!";
            modalPrizeCode.textContent = "";
            modalPrizeInstruction.textContent = "";
            copyButton.style.display = "none";
          } else {
            modalPrizeTitle.textContent = `Твоя награда ваучер, номиналом ${readableResult}`;
            modalPrizeCode.textContent = voucherCode || "";
            modalPrizeInstruction.textContent = voucherCode ? "Нажми на кнопку скопировать ниже" : "";
            copyButton.style.display = voucherCode ? "block" : "none";
          }
        }, 4500);
      })
      .catch(err => {
        console.error("Ошибка:", err);
        spinButton.disabled = false;
      });
  });

  modalClose.addEventListener('click', function() {
      registerModal.classList.remove('active');
  });

  copyButton.addEventListener("click", () => {
    const code = modalPrizeCode.textContent;
    navigator.clipboard.writeText(code).then(() => {
      copyButton.classList.add("copied");
      setTimeout(() => {
        copyButton.classList.remove("copied");
      }, 2000);
    });
  });

  document.querySelectorAll('[data-scroll-to]').forEach(btn => {
      btn.addEventListener('click', function () {
        const targetId = this.getAttribute('data-scroll-to');
        const targetSection = document.getElementById(targetId);
        if (targetSection) {
          window.scrollTo({
            top: targetSection.offsetTop - 80,
            behavior: 'smooth'
          });
        }
      });
    });

  const menuBtn = document.querySelector('.login-btn');
  const menuDropdown = document.getElementById('menuDropdown');

  menuBtn.addEventListener('click', (e) => {
    e.preventDefault();
    menuDropdown.classList.toggle('show');
  });

  document.addEventListener('click', (e) => {
    if (!menuBtn.contains(e.target) && !menuDropdown.contains(e.target)) {
      menuDropdown.classList.remove('show');
    }
  });

  document.querySelector('.dropdown-item:nth-child(1)').addEventListener('click', () => {
      document.getElementById('offcanvas-rank').classList.add('active');
      document.body.classList.add('no-scroll');
  });

  document.getElementById('close-offcanvas-rank').addEventListener('click', () => {
      document.getElementById('offcanvas-rank').classList.remove('active');
      document.body.classList.remove('no-scroll');
  });

  document.querySelector('.dropdown-item:nth-child(2)').addEventListener('click', () => {
      document.getElementById('offcanvas-faq').classList.add('active');
      document.body.classList.add('no-scroll');
  });

  document.getElementById('close-offcanvas-faq').addEventListener('click', () => {
      document.getElementById('offcanvas-faq').classList.remove('active');
      document.body.classList.remove('no-scroll');
  });

  document.querySelectorAll('.faq-question').forEach(question => {
      question.addEventListener('click', () => {
        const item = question.parentElement;
        item.classList.toggle('active');
      });
  });

  document.body.classList.add('modal-lock');

  const user = Telegram.WebApp.initDataUnsafe.user;
  const userId = user?.id;

  console.log("Telegram ID:", userId);

  const regBtn = document.getElementById("registerBtn");
  if (regBtn && userId) {
    regBtn.href = `https://1wvteh.com/casino/list?open=register&p=zx8u&sub1=${userId}`;
    regBtn.setAttribute("target", "_blank");
  }

  function showRegistrationModal() {
      const modal = document.getElementById("welcome-modal");
      const blur = document.querySelector(".blur-overlay");
      if (modal && blur) {
        modal.style.display = "block";
        blur.style.display = "block";
        document.body.classList.add("modal-lock");
        console.log("🔒 Пользователь не зарегистрирован — показали окно");
      }
  }

  function hideRegistrationModal() {
      const modal = document.getElementById("welcome-modal");
      const blur = document.querySelector(".blur-overlay");
      if (modal && blur) {
        modal.style.display = "none";
        blur.style.display = "none";
        document.body.classList.remove("modal-lock");
        console.log("✅ Скрыли окно и блюр");
      }
  }

  function checkRegistration(userId) {
      fetch(`/is-registered?user_id=${userId}`)
        .then(res => res.json())
        .then(data => {
          console.log("Ответ от сервера:", data);
          if (data.registered) {
            hideRegistrationModal();
          } else {
            showRegistrationModal();
          }
        })
        .catch(err => {
          console.error("❌ Ошибка при проверке регистрации:", err);
        });
  }

  if (userId) {
      checkRegistration(userId);
      setInterval(() => {
        checkRegistration(userId);
      }, 7000);
  }

  const RANK_NAMES = {
      novice: "Новичок",
      citizen: "Обыватель",
      gambler: "Азартный",
      lucky: "Фартовый",
      highroller: "Хайроллер",
      guardian: "Хранитель",
      legend: "Легенда"
  };

  function updateRankUI(rank) {
      const rankText = document.querySelector(".section-title span");
      if (rankText) {
        rankText.textContent = RANK_NAMES[rank] || rank;
      }
      document.querySelectorAll(".mission-node").forEach(node => {
        node.classList.remove("completed");
        if (node.dataset.rank === rank) {
          node.classList.add("completed");
        }
      });
  }

  function fetchAndShowRank(userId) {
      fetch(`/get-rank?user_id=${userId}`)
        .then(res => res.json())
        .then(data => {
          if (data.rank) {
            updateRankUI(data.rank);
          }
        })
        .catch(err => console.error("❌ Ошибка при получении ранга:", err));
  }

  document.querySelector('.dropdown-item:nth-child(1)').addEventListener('click', () => {
      document.getElementById('offcanvas-rank').classList.add('active');
      document.body.classList.add('no-scroll');
      if (userId) {
        fetchAndShowRank(userId);
      }
  });
});